# Generated by Django 5.1.2 on 2024-10-10 11:52

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('textmanager', '0001_initial'),
    ]

    operations = [
        migrations.AlterModelTable(
            name='category',
            table='textmanager_category',
        ),
        migrations.AlterModelTable(
            name='language',
            table='textmanager_language',
        ),
        migrations.AlterModelTable(
            name='languagetext',
            table='textmanager_language_text',
        ),
        migrations.AlterModelTable(
            name='text',
            table='textmanager_text',
        ),
    ]
